@@ -28,8 +28,9 @@ class DwCAReader(object):
 
     :param path: path to the Darwin Core Archive (either a zip/tgz file or a directory) to open.
     :type path: str
-    :param extensions_to_ignore: relative path (within the archive) of extension data files to\
-    ignore. This will improve performances and memory consumption with large archives.
+    :param extensions_to_ignore: relative path (within the archive) of extension data files to \
+    ignore. This will improve performances and memory consumption with large archives. Missing \
+    files are silently ignored.
     :type extensions_to_ignore: list
 
     :raises: :class:`dwca.exceptions.InvalidArchive`
@@ -88,7 +89,7 @@ class DwCAReader(object):
         #: An :class:`descriptors.ArchiveDescriptor` instance giving access to the archive
         #: descriptor (``meta.xml``)
         try:
-            self.descriptor = ArchiveDescriptor(self._read_additional_file(METAFILE_NAME),
+            self.descriptor = ArchiveDescriptor(self.open_included_file(METAFILE_NAME).read(),
                                                 files_to_ignore=extensions_to_ignore)
         except IOError as e:
             if e.errno == ENOENT:
@@ -210,10 +211,12 @@ class DwCAReader(object):
         if invalid:
             raise InvalidSimpleArchive()
 
-    def _read_additional_file(self, relative_path):
-        """Read an additional file in the archive and return its content."""
-        p = self.absolute_temporary_path(relative_path)
-        return open(p).read()
+    def open_included_file(self, relative_path, *args, **kwargs):
+        """Simple wrapper around Python's open build-in function.
+
+        To be used for reading only.
+        """
+        return open(self.absolute_temporary_path(relative_path), *args, **kwargs)
 
     def _parse_metadata_file(self):
         """Load the archive (scientific) Metadata file, parse it with\
@@ -242,7 +245,7 @@ class DwCAReader(object):
 
     def _parse_xml_included_file(self, relative_path):
         """Load, parse and returns (as ElementTree.Element) XML file located at relative_path."""
-        return ET.fromstring(self._read_additional_file(relative_path))
+        return ET.fromstring(self.open_included_file(relative_path).read())
 
     def _unzip_or_untar(self):
         """Create a temporary dir. and uncompress/unarchive self.archive_path there.
@@ -359,9 +362,9 @@ class GBIFResultsReader(DwCAReader):
     @property
     def citations(self):
         """Return the content of the citations.txt file included in the archive."""
-        return self._read_additional_file('citations.txt')
+        return self.open_included_file('citations.txt').read()
 
     @property
     def rights(self):
         """Return the content of the rights.txt file included in the archive."""
-        return self._read_additional_file('rights.txt')
+        return self.open_included_file('rights.txt').read()
