@@ -20,13 +20,36 @@ from .helpers import (GBIF_RESULTS_PATH, BASIC_ARCHIVE_PATH, EXTENSION_ARCHIVE_P
                       SUBDIR_ARCHIVE_PATH, SIMPLE_CSV, SIMPLE_CSV_EML, SIMPLE_CSV_DOS,
                       BASIC_ENCLOSED_ARCHIVE_PATH, INVALID_SIMPLE_TOOMUCH, INVALID_SIMPLE_TWO,
                       SIMPLE_CSV_NOTENCLOSED, NOMETADATA_PATH, DEFAULT_METADATA_FILENAME,
-                      BASIC_ARCHIVE_TGZ_PATH)
+                      BASIC_ARCHIVE_TGZ_PATH, INVALID_DESCRIPTOR)
 
 
 class TestDwCAReader(unittest.TestCase):
     # TODO: Move row-oriented tests to another test class
     """Unit tests for DwCAReader class."""
 
+    def test_open_included_file(self):
+        """Ensure DwCAReader.open_included_file work as expected."""
+        # Let's use it to read the raw core data file:
+        with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
+            f = dwca.open_included_file('occurrence.txt')
+
+            raw_occ = f.read()
+            self.assertTrue(raw_occ.endswith('betta splendens\n'))
+
+        # TODO: test more cases: opening mode, exceptions raised, ...
+
+    def test_descriptor_references_non_existent_data_field(self):
+        """Ensure InvalidArchive is raised when a file descriptor references non-existent field.
+
+        This ensure cases like http://dev.gbif.org/issues/browse/PF-2470 (descriptor contains
+        <field index="234" term="http://rs.gbif.org/terms/1.0/lastCrawled"/>, but has only 234
+        fields in data file) fail in a visible way (previously, archive just appeard empty).
+        """
+        with DwCAReader(INVALID_DESCRIPTOR) as dwca:
+            with self.assertRaises(InvalidArchive):
+                for row in dwca:
+                    pass
+
     def test_use_extensions(self):
         """Ensure the .use_extensions attribute of DwCAReader works as intended."""
         with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
@@ -591,9 +614,22 @@ class TestDwCAReader(unittest.TestCase):
                 self.assertEqual(0, len(rows[2].extensions))
                 self.assertEqual(0, len(rows[3].extensions))
 
+        # And here, we check it is silently ignored and everything works in case we ask to
+        # ignore an unexisting extension
+        with DwCAReader(MULTIEXTENSIONS_ARCHIVE_PATH,
+                        extensions_to_ignore="helloworld.txt") as multi_dwca:
+
+            rows = list(multi_dwca)
+
+            # 3 vernacular names + 2 taxon descriptions
+            self.assertEqual(5, len(rows[0].extensions))
+            # 1 Vernacular name, no taxon description
+            self.assertEqual(1, len(rows[1].extensions))
+            # No extensions for this core row
+            self.assertEqual(0, len(rows[2].extensions))
+
     def test_row_rowtype(self):
         """Test the rowtype attribute of rows (for Core and extensions)."""
-
         with DwCAReader(EXTENSION_ARCHIVE_PATH) as star_dwca:
             taxon_qn = "http://rs.tdwg.org/dwc/terms/Taxon"
             vernacular_qn = "http://rs.gbif.org/terms/1.0/VernacularName"
